@@ -1,7 +1,7 @@
 import requests
 import json
 
-SNOVIO_API_URL = 'https://api.snov.io/v1/'
+SNOVIO_API_URL = 'https://api.snov.io/'
 SNOVIO_USER_ID = 'your-user-id'
 SNOVIO_USER_SECRET = 'your-user-secret'
 
@@ -32,7 +32,6 @@ class SnovioAPI:
         self.client_id = client_id
         self.client_secret = client_secret
 
-
     def get_access_token(self, client_id, client_secret):
         auth_endpoint = 'oauth/access_token'
         params = {
@@ -41,9 +40,11 @@ class SnovioAPI:
             'client_secret': client_secret
         }
 
-        response = requests.post(SNOVIO_API_URL + 'v1/' + auth_endpoint, data=params)
-        return response.json()['access_token']
-
+        response = requests.post(
+            SNOVIO_API_URL + 'v1/' + auth_endpoint, data=params
+        )
+        resText = response.text.encode('ascii', 'ignore')
+        return json.loads(resText)['access_token']
 
     def _request(self, endpoint, data):
         if self.is_parameter_in_uri(endpoint):
@@ -55,7 +56,9 @@ class SnovioAPI:
 
         if self.get_http_method(endpoint) == 'GET':
             response = requests.get(
-                SNOVIO_API_URL + self.get_endpoint_version(endpoint) + endpoint, data=data
+                SNOVIO_API_URL + \
+                self.get_endpoint_version(endpoint) + \
+                endpoint, data=data
             )
         else:
             response = requests.post(
@@ -95,7 +98,7 @@ class SnovioAPI:
 
     @staticmethod
     def get_http_method(endpoint):
-        GET_endpoints = ['domain-emails-with-info']
+        GET_endpoints = ['domain-emails-with-info']  # TODO: add other GET-endpoints
         if endpoint in GET_endpoints:
             return 'GET'
         return 'POST'
@@ -182,4 +185,4 @@ if __name__ == "__main__":
     # get_profile_by_email = snovio.get_profile_by_email({
     #    'email': 'lizi.hamer@octagon.com',
     # })
-    # print(get_profile_by_email)
\ No newline at end of file
+    # print(get_profile_by_email)
